@@ -1,22 +1,25 @@
-from flask import render_template, flash, redirect, session, url_for, request, g
+from flask import render_template, flash, redirect, session, url_for, request, g, current_app
 from flask.ext.login import login_user, logout_user, current_user, login_required
 from flask.ext.wtf import Required, Length, validators, EqualTo, PasswordField
 from flask.ext.babel import gettext, lazy_gettext
 
-from flask.ext.appbuilder.views import *
 from models import *
-from ..forms import BS3PasswordFieldWidget
 from forms import *
-
-
-from app import app, db, lm, oid
+from flask.ext.appbuilder.views import BaseView, GeneralView, SimpleFormView, AdditionalLinkItem, expose
+from ..forms import BS3PasswordFieldWidget
 from flask.ext.appbuilder.models.datamodel import SQLAModel
-from config import AUTH_TYPE, APP_NAME, APP_THEME
 
+from openid.extensions import ax
+from openid.extensions.sreg import SRegRequest, SRegResponse
+from openid.consumer.consumer import Consumer, SUCCESS, CANCEL
+from openid.consumer import discover
+from flask.ext.openid import SessionWrapper, OpenIDResponse
+
+#try:
+#    from app import app, db, lm, oid
+#except ImportError:
+#    raise Exception('app,db,lm,oid not found please use required skeleton application see documentation')
 
-AUTH_OID = 0
-AUTH_DB = 1
-AUTH_LDAP = 2
 
 
 
@@ -26,7 +29,7 @@ AUTH_LDAP = 2
 class PermissionGeneralView(GeneralView):
     route_base = '/permissions'
     
-    datamodel = SQLAModel(Permission, db.session)
+    datamodel = SQLAModel(Permission)
 
     list_title = lazy_gettext('List Base Permissions')
     show_title = lazy_gettext('Show Base Permission')
@@ -42,7 +45,7 @@ class PermissionGeneralView(GeneralView):
 class ViewMenuGeneralView(GeneralView):
     route_base = '/viewmenus'
     
-    datamodel = SQLAModel(ViewMenu, db.session)
+    datamodel = SQLAModel(ViewMenu)
 
     list_title = lazy_gettext('List View Menus')
     show_title = lazy_gettext('Show View Menu')
@@ -59,7 +62,7 @@ class ViewMenuGeneralView(GeneralView):
 class PermissionViewGeneralView(GeneralView):
     route_base = '/permissionviews'
     
-    datamodel = SQLAModel(PermissionView , db.session)
+    datamodel = SQLAModel(PermissionView )
 
     list_title = lazy_gettext('List Permissions on Views/Menus')
     show_title = lazy_gettext('Show Permission on Views/Menus')
@@ -117,7 +120,7 @@ class ResetPasswordView(SimpleFormView):
 
 class UserGeneralView(GeneralView):
     route_base = '/users'
-    datamodel = SQLAModel(User, db.session)
+    datamodel = SQLAModel(User)
     
 
     list_title = lazy_gettext('List Users')
@@ -154,23 +157,33 @@ class UserGeneralView(GeneralView):
 
     show_additional_links = []
 
+
+class UserOIDGeneralView(UserGeneralView):
+    @expose('/userinfo/')
+    def userinfo(self):
+        widgets = self._get_show_widget(g.user.id)
+
+        return render_template(self.show_template,
+                           title = self.user_info_title,
+                           widgets = widgets,
+                           baseapp = self.baseapp,
+                           )
+
+    def _init_forms(self):
+        super(UserGeneralView, self)._init_forms()
+        self.add_form.password = None
+
+class UserDBGeneralView(UserGeneralView):
     def __init__(self, **kwargs):
-        if AUTH_TYPE == AUTH_DB:
-            self.show_additional_links = [(AdditionalLinkItem('resetpassword', self.lnk_reset_password,"/resetpassword/form","lock"))]
-        super(UserGeneralView, self).__init__(**kwargs)
+        self.show_additional_links = [(AdditionalLinkItem('resetpassword', self.lnk_reset_password,"/resetpassword/form","lock"))]
+        super(UserDBGeneralView, self).__init__(**kwargs)
 
     @expose('/userinfo/')
     def userinfo(self):
-        item = g.user
-
         additional_links = None
 
-        if AUTH_TYPE == AUTH_DB:
-                show_additional_links = [AdditionalLinkItem('resetmypassword', self.lnk_reset_password,"/resetmypassword/form","lock")]
-                widgets = self._get_show_widget(item.id, show_additional_links = show_additional_links)
-        else:
-            widgets = self._get_show_widget(item.id)
-
+        show_additional_links = [AdditionalLinkItem('resetmypassword', self.lnk_reset_password,"/resetmypassword/form","lock")]
+        widgets = self._get_show_widget(g.user.id, show_additional_links = show_additional_links)
         return render_template(self.show_template,
                            title = self.user_info_title,
                            widgets = widgets,
@@ -180,27 +193,22 @@ class UserGeneralView(GeneralView):
 
     def _init_forms(self):
         super(UserGeneralView, self)._init_forms()
-        if AUTH_TYPE == AUTH_DB:
-            self.add_form.password = PasswordField('Password', 
-                                                   description=self.description_columns['password'],
-                                                   widget=BS3PasswordFieldWidget())
-            self.add_form.conf_password = PasswordField('Confirm Password',
-                                            default=self.add_form.password,
-                                            description=self.description_columns['conf_password'],
-                                            validators=[EqualTo('password',message=u'Passwords must match')],
-                                            widget=BS3PasswordFieldWidget())
-            if 'password' not in self.add_columns:
-                self.add_columns = self.add_columns + ['password', 'conf_password']
-        else:
-            self.add_form.password = None
-
+        self.add_form.password = PasswordField('Password', 
+                                 description=self.description_columns['password'],
+                                 widget=BS3PasswordFieldWidget())
+        self.add_form.conf_password = PasswordField('Confirm Password',
+                                 default=self.add_form.password,
+                                 description=self.description_columns['conf_password'],
+                                 validators=[EqualTo('password',message=u'Passwords must match')],
+                                 widget=BS3PasswordFieldWidget())
+        if 'password' not in self.add_columns:
+            self.add_columns = self.add_columns + ['password', 'conf_password']
+        
 
 class RoleGeneralView(GeneralView):
     route_base = '/roles'
     
-    datamodel = SQLAModel(Role, db.session)
-
-    related_views = [PermissionViewGeneralView(), UserGeneralView()]
+    datamodel = SQLAModel(Role)
 
     list_title = lazy_gettext('List Roles')
     show_title = lazy_gettext('Show Role')
@@ -225,27 +233,22 @@ class AuthView(BaseView):
     
     title = lazy_gettext('Sign In')
 
-    @expose('/login/', methods = ['GET', 'POST'])
-    @oid.loginhandler
-    def login(self):
-        if AUTH_TYPE == AUTH_OID: return self._login_oid()
-        if AUTH_TYPE == AUTH_DB: return self._login_db()
-
     @expose('/logout/')
     def logout(self):
         logout_user()
         return redirect('/')
 
-    def _login_db(self):
+
+class AuthDBView(AuthView):        
+
+    @expose('/login/', methods = ['GET', 'POST'])
+    def login(self):
         if g.user is not None and g.user.is_authenticated():
             return redirect('/')
         form = LoginForm_db()
         if form.validate_on_submit():
-            if form.username.data is None or form.username.data == "":
-                flash(unicode(self.invalid_login_message),'warning')
-                return redirect('/login')
-            user = User.query.filter_by(username = form.username.data, password = form.password.data).first()
-            if user is None or (not user.is_active()):
+            user = self.baseapp.sm.auth_user_db(form.username.data, form.password.data)
+            if not user:
                 flash(unicode(self.invalid_login_message),'warning')
                 return redirect('/login')
             login_user(user, remember = False)
@@ -256,46 +259,56 @@ class AuthView(BaseView):
                                                 baseapp = self.baseapp
                                                 )
 
-    def _login_oid(self):
+class AuthOIDView(AuthView):
+    
+
+    @expose('/login/', methods = ['GET', 'POST'])
+    def login(self, flag = True):
+        if flag:
+            self.oid_login_handler(self.login, self.baseapp.sm.oid)
         if g.user is not None and g.user.is_authenticated():
             return redirect('/')
         form = LoginForm_oid()
         if form.validate_on_submit():
             session['remember_me'] = form.remember_me.data
-            return oid.try_login(form.openid.data, ask_for = ['email'])
+            return self.baseapp.sm.oid.try_login(form.openid.data, ask_for = ['email'])
         return render_template(self.login_oid_template,
                 title = self.title,
                 form = form,
-                providers = app.config['OPENID_PROVIDERS'],
+                providers = self.baseapp.app.config['OPENID_PROVIDERS'],
                 baseapp = self.baseapp
                 )
 
+    def oid_login_handler(self, f, oid):
+        if request.args.get('openid_complete') != u'yes':
+            return f(False)
+        consumer = Consumer(SessionWrapper(self), oid.store_factory())
+        openid_response = consumer.complete(request.args.to_dict(),
+                                                oid.get_current_url())
+        if openid_response.status == SUCCESS:
+            return oid.after_login_func(OpenIDResponse(openid_response))
+        elif openid_response.status == CANCEL:
+            oid.signal_error(u'The request was cancelled')
+            return redirect(oid.get_current_url())
+        oid.signal_error(u'OpenID authentication error')
+        return redirect(oid.get_current_url())
 
-def _after_login_oid(resp):
-    if resp.email is None or resp.email == "":
-        flash(gettext('Invalid login. Please try again.'),'warning')
-        return redirect('appbuilder/general/security/login_oid.html')
-    user = User.query.filter_by(email = resp.email).first()
-    if user is None:
-        flash(gettext('Invalid login. Please try again.'),'warning')
-        return redirect('appbuilder/general/security/login_oid.html')
-    remember_me = False
-    if 'remember_me' in session:
-        remember_me = session['remember_me']
-        session.pop('remember_me', None)
+    def after_login(self, resp):
+        if resp.email is None or resp.email == "":
+            flash(gettext('Invalid login. Please try again.'),'warning')
+            return redirect('appbuilder/general/security/login_oid.html')
+        user = self.baseapp.sm.auth_user_oid(resp.email)
+        if user is None:
+            flash(gettext('Invalid login. Please try again.'),'warning')
+            return redirect('appbuilder/general/security/login_oid.html')
+        remember_me = False
+        if 'remember_me' in session:
+            remember_me = session['remember_me']
+            session.pop('remember_me', None)
+
+        login_user(user, remember = remember_me)
+        return redirect('/')
 
-    login_user(user, remember = remember_me)
-    return redirect('/')
-
-@oid.after_login
-def _after_login(resp):
-    if AUTH_TYPE == AUTH_OID: return _after_login_oid(resp)
 
 
-@app.before_request
-def before_request():
-    g.user = current_user
 
-@lm.user_loader
-def load_user(id):
-    return User.query.get(int(id))
